@@ -1,3 +1,4 @@
+import inspect
 import json
 import logging
 import os
@@ -127,8 +128,8 @@ class LambdaPowertoolsFormatter(BasePowertoolsFormatter):
 
         super(LambdaPowertoolsFormatter, self).__init__(datefmt=self.datefmt)
 
-        keys_combined = {**self._build_default_keys(), **kwargs}
-        self.log_format.update(**keys_combined)
+        self.keys_combined = {**self._build_default_keys(), **kwargs}
+        self.log_format.update(**self.keys_combined)
 
     def serialize(self, log: Dict) -> str:
         """Serialize structured log dict to JSON str"""
@@ -187,6 +188,7 @@ class LambdaPowertoolsFormatter(BasePowertoolsFormatter):
 
     def clear_state(self):
         self.log_format = dict.fromkeys(self.log_record_order)
+        self.log_format.update(**self.keys_combined)
 
     @staticmethod
     def _build_default_keys():
@@ -285,3 +287,7 @@ class LambdaPowertoolsFormatter(BasePowertoolsFormatter):
 
 
 JsonFormatter = LambdaPowertoolsFormatter  # alias to previous formatter
+
+
+# Fetch current and future parameters from PowertoolsFormatter that should be reserved
+RESERVED_FORMATTER_CUSTOM_KEYS: List[str] = inspect.getfullargspec(LambdaPowertoolsFormatter).args[1:]
