@@ -1,11 +1,16 @@
-from aws_lambda_powertools.utilities.data_classes.appsync_resolver_event import AppSyncResolverEvent
+"""
+Event Source Data Classes utility provides classes self-describing Lambda event sources.
+"""
 
 from .alb_event import ALBEvent
 from .api_gateway_proxy_event import APIGatewayProxyEvent, APIGatewayProxyEventV2
+from .appsync_resolver_event import AppSyncResolverEvent
 from .cloud_watch_logs_event import CloudWatchLogsEvent
+from .code_pipeline_job_event import CodePipelineJobEvent
 from .connect_contact_flow_event import ConnectContactFlowEvent
 from .dynamo_db_stream_event import DynamoDBStreamEvent
 from .event_bridge_event import EventBridgeEvent
+from .event_source import event_source
 from .kinesis_stream_event import KinesisStreamEvent
 from .s3_event import S3Event
 from .ses_event import SESEvent
@@ -18,6 +23,7 @@ __all__ = [
     "AppSyncResolverEvent",
     "ALBEvent",
     "CloudWatchLogsEvent",
+    "CodePipelineJobEvent",
     "ConnectContactFlowEvent",
     "DynamoDBStreamEvent",
     "EventBridgeEvent",
@@ -26,4 +32,5 @@ __all__ = [
     "SESEvent",
     "SNSEvent",
     "SQSEvent",
+    "event_source",
 ]
