@@ -6,6 +6,7 @@ from aws_lambda_powertools.utilities.data_classes.common import BaseProxyEvent,
 class ALBEventRequestContext(DictWrapper):
     @property
     def elb_target_group_arn(self) -> str:
+        """Target group arn for your Lambda function"""
         return self["requestContext"]["elb"]["targetGroupArn"]
 
 
@@ -15,20 +16,13 @@ class ALBEvent(BaseProxyEvent):
     Documentation:
     --------------
     - https://docs.aws.amazon.com/lambda/latest/dg/services-alb.html
+    - https://docs.aws.amazon.com/elasticloadbalancing/latest/application/lambda-functions.html
     """
 
     @property
     def request_context(self) -> ALBEventRequestContext:
         return ALBEventRequestContext(self._data)
 
-    @property
-    def http_method(self) -> str:
-        return self["httpMethod"]
-
-    @property
-    def path(self) -> str:
-        return self["path"]
-
     @property
     def multi_value_query_string_parameters(self) -> Optional[Dict[str, List[str]]]:
         return self.get("multiValueQueryStringParameters")
