@@ -1,3 +1,5 @@
+from .apigw import ApiGatewayEnvelope
+from .apigwv2 import ApiGatewayV2Envelope
 from .base import BaseEnvelope
 from .cloudwatch import CloudWatchLogsEnvelope
 from .dynamodb import DynamoDBStreamEnvelope
@@ -7,6 +9,8 @@ from .sns import SnsEnvelope, SnsSqsEnvelope
 from .sqs import SqsEnvelope
 
 __all__ = [
+    "ApiGatewayEnvelope",
+    "ApiGatewayV2Envelope",
     "CloudWatchLogsEnvelope",
     "DynamoDBStreamEnvelope",
     "EventBridgeEnvelope",
